==> haskell-mockery-0.3.5-1-armv7h.pkg.tar.xz: usr/share/haskell/register/haskell-mockery.sh <==
#!/bin/sh
export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: mockery
version: 0.3.5
id: mockery-0.3.5-4WWGYsbpmBm6tBRc7ZBG0W
key: mockery-0.3.5-4WWGYsbpmBm6tBRc7ZBG0W
license: MIT
copyright: (c) 2015-2016 Simon Hengel
maintainer: Simon Hengel <sol@typeful.net>
synopsis: Support functions for automated testing
description:
    Support functions for automated testing
category: Testing
author: Simon Hengel <sol@typeful.net>
exposed: True
indefinite: False
exposed-modules:
    Test.Mockery.Directory Test.Mockery.Environment
    Test.Mockery.Logging
hidden-modules: Paths_mockery
abi: af90ae342a0f07f66741fbc605aff048
trusted: False
import-dirs: /usr/lib/ghc-8.2.2/site-local/mockery-0.3.5
library-dirs: /usr/lib/ghc-8.2.2/site-local/mockery-0.3.5
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/arm-linux-ghc-8.2.2/mockery-0.3.5
hs-libraries: HSmockery-0.3.5-4WWGYsbpmBm6tBRc7ZBG0W
depends:
    base-4.10.1.0 base-compat-0.9.3-915GC5pH10BBmcMnCvMsPA
    bytestring-0.10.8.2 temporary-1.2.1.1-7a1ypWDsHB4EWhBxWwtUro
    directory-1.3.0.2 filepath-1.4.1.2
    logging-facade-0.3.0-Lq2IPrLgBfrJhxMxXVp7QS
abi-depends: base-4.10.1.0=0ea45191c57c268b2351cb731ab6a0d6
             base-compat-0.9.3-915GC5pH10BBmcMnCvMsPA=b23a246a62afd271167dd1ea1b77583b
             bytestring-0.10.8.2=4b2726b654ceeff6535e698a2a1e724e
             temporary-1.2.1.1-7a1ypWDsHB4EWhBxWwtUro=b8bff4b84b25638f1f5ef8924bbd6e32
             directory-1.3.0.2=7b913664ccd770192b307d7c4c6817cc
             filepath-1.4.1.2=a40cd48e5480796e558f3c29652ee19a
             logging-facade-0.3.0-Lq2IPrLgBfrJhxMxXVp7QS=1e64a8b9e88abcefd43bb1efb7a913da
haddock-interfaces: /usr/share/doc/haskell-mockery/html/mockery.haddock
haddock-html: /usr/share/doc/haskell-mockery/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-mockery-0.3.5-2-armv7h.pkg.tar.xz: usr/share/haskell/register/haskell-mockery.sh <==
#!/bin/sh
export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: mockery
version: 0.3.5
id: mockery-0.3.5-FhViVxrocYrLDE9FW0puLl
key: mockery-0.3.5-FhViVxrocYrLDE9FW0puLl
license: MIT
copyright: (c) 2015-2016 Simon Hengel
maintainer: Simon Hengel <sol@typeful.net>
synopsis: Support functions for automated testing
description:
    Support functions for automated testing
category: Testing
author: Simon Hengel <sol@typeful.net>
exposed: True
indefinite: False
exposed-modules:
    Test.Mockery.Directory Test.Mockery.Environment
    Test.Mockery.Logging
hidden-modules: Paths_mockery
abi: ee84f68b6c0bcdc9acb481b5fb3ae1fd
trusted: False
import-dirs: /usr/lib/ghc-8.2.2/site-local/mockery-0.3.5
library-dirs: /usr/lib/ghc-8.2.2/site-local/mockery-0.3.5
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/arm-linux-ghc-8.2.2/mockery-0.3.5
hs-libraries: HSmockery-0.3.5-FhViVxrocYrLDE9FW0puLl
depends:
    base-4.10.1.0 base-compat-0.9.3-915GC5pH10BBmcMnCvMsPA
    bytestring-0.10.8.2 temporary-1.2.1.1-2QgeQJQfCPf69oxJVZZ5cG
    directory-1.3.0.2 filepath-1.4.1.2
    logging-facade-0.3.0-Lq2IPrLgBfrJhxMxXVp7QS
abi-depends: base-4.10.1.0=0ea45191c57c268b2351cb731ab6a0d6
             base-compat-0.9.3-915GC5pH10BBmcMnCvMsPA=b23a246a62afd271167dd1ea1b77583b
             bytestring-0.10.8.2=4b2726b654ceeff6535e698a2a1e724e
             temporary-1.2.1.1-2QgeQJQfCPf69oxJVZZ5cG=ab0f4b4f4a78e7c697cf1bced8c58e9c
             directory-1.3.0.2=7b913664ccd770192b307d7c4c6817cc
             filepath-1.4.1.2=a40cd48e5480796e558f3c29652ee19a
             logging-facade-0.3.0-Lq2IPrLgBfrJhxMxXVp7QS=1e64a8b9e88abcefd43bb1efb7a913da
haddock-interfaces: /usr/share/doc/haskell-mockery/html/mockery.haddock
haddock-html: /usr/share/doc/haskell-mockery/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
